
Contribute
##########

Thank you for your interest in contributing to Ansys Sphinx theme! Contributions are welcome
to make the project better, whether it's fixing bugs, adding new features, or
improving documentation. Below are the guidelines to follow when contributing.


.. grid::
    :gutter: 1 2 3 3
    :padding: 1 2 3 3

    .. grid-item-card:: :fa:`user` User
        :link: contribute/user
        :link-type: doc

        Learn how to contribute as a user.

    .. grid-item-card:: :fa:`code-fork` Developer
        :link: contribute/developer
        :link-type: doc

        Learn how to contribute as a developer.


.. toctree::
    :hidden:
    :maxdepth: 1
    :caption: Contribute

    User<contribute/user>
    Developer<contribute/developer>